manage package
==============

Submodules
----------

manage.cli module
-----------------

.. automodule:: manage.cli
    :members:
    :undoc-members:
    :show-inheritance:

manage.manage module
--------------------

.. automodule:: manage.manage
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: manage
    :members:
    :undoc-members:
    :show-inheritance:
